package
{
import mx.effects.easing.Linear;

import spark.effects.easing.IEaser;

/**
 * This class allows users of the older "easing functions" in Flex 3 to be used with
 * Flex 4 effects. The effects in Flex 4 use instances of the new IEaser interface
 * to affect easing, not the older Function approach of Flex 3. Through this class,
 * a developer can declare an instance of IEaser that uses an underlying Flex 3 easing
 * function to perform the work. Given that easing function and the elapsed fraction
 * of the animation at any frame, we can use the older easing functions to calculate
 * an eased fraction, which is then used by the Flex 4 effects to create eased behavior.
 * 
 * @see mx.effects.easing
 */
public class EasingFunctionWrapper implements IEaser
{
    /**
     * The Flex 3 easing function that is wrapped by this IEaser instance.
     * This Function must be of the
     * form of all easing functions from Flex 3, which take 4 Numbers
     * and return a Number. See any of the Flex 3 easing classes for
     * more information.
     * 
     * @default Linear.easeNone
     * 
     * @see Cubic#easeIn
     */
    public var easingFunction:Function = Linear.easeNone;
    
    /**
     * The constructor takes a function reference to the Flex 3 easing
     * function that will be used to calculate the eased fraction in the
     * ease() function.
     * 
     * @param easingFunction The easing function wrapped by this IEaser
     * instance. A value of null is equivalent to Linear.easeNone.
     * 
     * @return Number the eased fraction
     */
    public function EasingFunctionWrapper(easingFunction:Function = null)
    {
        if (easingFunction != null)
            this.easingFunction = easingFunction;
    }

    /**
     * @copy spark.effects.easing.IEaser#ease
     */
    public function ease(fraction:Number):Number
    {
        return easingFunction(fraction, 0, 1, 1);
    }
    
}
}